@@ -72,11 +72,11 @@ gboolean meta_compositor_is_switching_workspace (MetaCompositor *compositor);
 gboolean meta_compositor_drag_window (MetaCompositor       *compositor,
                                       MetaWindow           *window,
                                       MetaGrabOp            grab_op,
+                                      MetaDragWindowFlags   flags,
                                       ClutterInputDevice   *device,
                                       ClutterEventSequence *sequence,
                                       uint32_t              timestamp,
-                                      graphene_point_t     *pos_hint,
-                                      ClutterActor         *grab_actor);
+                                      graphene_point_t     *pos_hint);
 
 MetaWindowDrag * meta_compositor_get_current_window_drag (MetaCompositor *compositor);
 
